==> haskell-data-endian-0.1.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-endian.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-endian
version:              0.1.1
visibility:           public
id:                   data-endian-0.1.1-A76DF2AS0nVBqqp9FXAKCE
key:                  data-endian-0.1.1-A76DF2AS0nVBqqp9FXAKCE
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-endian
synopsis:             Endian-sensitive data
description:
    This package provides helpers for converting endian-sensitive data.

category:             Data
abi:                  6fcb4dc36074cc6faa62de53dcafaee9
exposed:              True
exposed-modules:      Data.Endian
import-dirs:          /usr/lib/ghc-9.0.2/site-local/data-endian-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/data-endian-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/data-endian-0.1.1
hs-libraries:         HSdata-endian-0.1.1-A76DF2AS0nVBqqp9FXAKCE
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-data-endian/html/data-endian.haddock
haddock-html:         /usr/share/doc/haskell-data-endian/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-endian-0.1.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-endian.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-endian
version:              0.1.1
visibility:           public
id:                   data-endian-0.1.1-8VgB7oHHi3LDrYxCrUtoWs
key:                  data-endian-0.1.1-8VgB7oHHi3LDrYxCrUtoWs
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-endian
synopsis:             Endian-sensitive data
description:
    This package provides helpers for converting endian-sensitive data.

category:             Data
abi:                  771e9db2dc3c2359695d46d3ade6192f
exposed:              True
exposed-modules:      Data.Endian
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-endian-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-endian-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-endian
hs-libraries:         HSdata-endian-0.1.1-8VgB7oHHi3LDrYxCrUtoWs
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-data-endian/html/data-endian.haddock
haddock-html:         /usr/share/doc/haskell-data-endian/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
